@@ -24,14 +24,10 @@ class OAuth2Config(BaseModel):
     """OAuth module configuration."""
 
     providers: list[OAuth2ProviderConfig] = Field(
-        default_factory=list,
-        description="List of OAuth providers to enable."
+        default_factory=list, description="List of OAuth providers to enable."
     )
 
-    login_callback: Callable | None = Field(
-        None,
-        description=callback_description
-    )
+    login_callback: Callable | None = Field(None, description=callback_description)
     login_response_model: BaseModel | None = None
 
     enable_redirect_endpoint: bool = True
@@ -39,9 +35,7 @@ class OAuth2Config(BaseModel):
     def add_provider(self, name: str, client_id: str, client_secret: str):
         self.providers.append(
             OAuth2ProviderConfig(
-                provider=name,
-                client_id=client_id,
-                client_secret=client_secret
+                provider=name, client_id=client_id, client_secret=client_secret
             )
         )
 
