@@ -23,11 +23,11 @@ def parse_user(user: dict) -> OAuth2UserInfo:
 
 
 discord = OAuth2Provider(
-    api_base_url='https://discordapp.com/api/',
-    token_endpoint='https://discordapp.com/api/oauth2/token',
-    authorization_endpoint='https://discordapp.com/api/oauth2/authorize',
-    userinfo_endpoint='https://discordapp.com/api/users/%40me',
-    revocation_endpoint='https://discordapp.com/api/oauth2/token/revoke',
+    api_base_url="https://discordapp.com/api/",
+    token_endpoint="https://discordapp.com/api/oauth2/token",
+    authorization_endpoint="https://discordapp.com/api/oauth2/authorize",
+    userinfo_endpoint="https://discordapp.com/api/users/%40me",
+    revocation_endpoint="https://discordapp.com/api/oauth2/token/revoke",
     userinfo_parser=parse_user,
     scope="identify email",
 )
