@@ -25,9 +25,7 @@ async def get_user_info(provider, access_token: str):
     async with httpx.AsyncClient() as client:
         res = await client.get(
             provider.userinfo_endpoint,
-            headers={
-                "Authorization": f"Bearer {access_token}"
-            }
+            headers={"Authorization": f"Bearer {access_token}"},
         )
     if res.status_code != 200:
         return None
